==> jc-1.4.0.tar.gz: java/text/MessageFormat__24MessageFormatElement.h <==
// final class java.text.MessageFormat$MessageFormatElement

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c55dd863b5b10fd5 java_text_MessageFormat__24MessageFormatElement

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_MessageFormat__24MessageFormatElement_H_
#define _JC_java_text_MessageFormat__24MessageFormatElement_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_Format$object;
struct _jc_java_text_MessageFormat__241$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_java_text_MessageFormat__24MessageFormatElement$sub_refs	_jc_java_text_MessageFormat__24MessageFormatElement$sub_refs;
typedef struct _jc_java_text_MessageFormat__24MessageFormatElement$sub_nonrefs	_jc_java_text_MessageFormat__24MessageFormatElement$sub_nonrefs;
typedef struct _jc_java_text_MessageFormat__24MessageFormatElement$refs	_jc_java_text_MessageFormat__24MessageFormatElement$refs;
typedef struct _jc_java_text_MessageFormat__24MessageFormatElement$nonrefs	_jc_java_text_MessageFormat__24MessageFormatElement$nonrefs;
typedef struct _jc_java_text_MessageFormat__24MessageFormatElement$object	_jc_java_text_MessageFormat__24MessageFormatElement$object;

typedef struct _jc_java_text_MessageFormat__24MessageFormatElement$fields_struct	_jc_java_text_MessageFormat__24MessageFormatElement$fields_struct;
typedef const struct _jc_java_text_MessageFormat__24MessageFormatElement$vmethods	_jc_java_text_MessageFormat__24MessageFormatElement$vmethods;
typedef const struct _jc_java_text_MessageFormat__24MessageFormatElement$vtable	_jc_java_text_MessageFormat__24MessageFormatElement$vtable;
typedef const struct _jc_java_text_MessageFormat__24MessageFormatElement$vtype	_jc_java_text_MessageFormat__24MessageFormatElement$vtype;

// Class fields structure
struct _jc_java_text_MessageFormat__24MessageFormatElement$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Number;
	struct _jc_java_lang_Class$object	*class__24java__24util__24Date;
};
extern _jc_java_text_MessageFormat__24MessageFormatElement$fields_struct _jc_java_text_MessageFormat__24MessageFormatElement$class_fields;

// Constructors
extern void _jc_java_text_MessageFormat__24MessageFormatElement$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_text_MessageFormat__24MessageFormatElement$object *);
extern void _jc_java_text_MessageFormat__24MessageFormatElement$method$_init$31edac7687292d89(_jc_env *, struct _jc_java_text_MessageFormat__24MessageFormatElement$object *, struct _jc_java_text_MessageFormat__241$object *);

// Virtual methods
extern void _jc_java_text_MessageFormat__24MessageFormatElement$method$setLocale$6eaa1a56408d8bc9(_jc_env *, struct _jc_java_text_MessageFormat__24MessageFormatElement$object *, struct _jc_java_util_Locale$object *);

// Virtual method descriptors
extern _jc_method _jc_java_text_MessageFormat__24MessageFormatElement$method_info$setLocale$6eaa1a56408d8bc9;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_java_text_MessageFormat__24MessageFormatElement$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_java_text_MessageFormat__24MessageFormatElement$vmethods {
	void	(*setLocale$6eaa1a56408d8bc9)(_jc_env *, struct _jc_java_text_MessageFormat__24MessageFormatElement$object *, struct _jc_java_util_Locale$object *);
};

// Vtable
struct _jc_java_text_MessageFormat__24MessageFormatElement$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_MessageFormat__24MessageFormatElement$vmethods	java_text_MessageFormat__24MessageFormatElement;
};

// Vtype
struct _jc_java_text_MessageFormat__24MessageFormatElement$vtype {
	_jc_type			type;
	_jc_java_text_MessageFormat__24MessageFormatElement$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_MessageFormat__24MessageFormatElement$sub_refs {
	struct _jc_java_text_Format$object	*setFormat;
	struct _jc_java_text_Format$object	*format;
	struct _jc_java_lang_Class$object	*formatClass;
	struct _jc_java_lang_String$object	*type;
	struct _jc_java_lang_String$object	*style;
	struct _jc_java_lang_String$object	*trailer;
};

// Reference instance fields (object)
struct _jc_java_text_MessageFormat__24MessageFormatElement$refs {
    _jc_java_text_MessageFormat__24MessageFormatElement$sub_refs	java_text_MessageFormat__24MessageFormatElement;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_MessageFormat__24MessageFormatElement$sub_nonrefs {
	jint	argNumber;
};

// Non-reference instance fields (object)
struct _jc_java_text_MessageFormat__24MessageFormatElement$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_MessageFormat__24MessageFormatElement$sub_nonrefs	java_text_MessageFormat__24MessageFormatElement;
};

// Object instance structure
struct _jc_java_text_MessageFormat__24MessageFormatElement$object {
	_jc_java_text_MessageFormat__24MessageFormatElement$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_MessageFormat__24MessageFormatElement$vtype	*vtype;
	_jc_java_text_MessageFormat__24MessageFormatElement$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_MessageFormat__24MessageFormatElement$vtype _jc_java_text_MessageFormat__24MessageFormatElement$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_MessageFormat__24MessageFormatElement, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_MessageFormat__24MessageFormatElement$class_object;

#endif	/* _JC_java_text_MessageFormat__24MessageFormatElement_H_ */

==> jc-1.4.5.tar.gz: java/text/MessageFormat__24MessageFormatElement.h <==
// final class java.text.MessageFormat$MessageFormatElement

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c55dd863b5b10fd5 java_text_MessageFormat__24MessageFormatElement

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_text_MessageFormat__24MessageFormatElement_H_
#define _JC_java_text_MessageFormat__24MessageFormatElement_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_Format$object;
struct _jc_java_text_MessageFormat__241$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_java_text_MessageFormat__24MessageFormatElement$sub_refs	_jc_java_text_MessageFormat__24MessageFormatElement$sub_refs;
typedef struct _jc_java_text_MessageFormat__24MessageFormatElement$sub_nonrefs	_jc_java_text_MessageFormat__24MessageFormatElement$sub_nonrefs;
typedef struct _jc_java_text_MessageFormat__24MessageFormatElement$refs	_jc_java_text_MessageFormat__24MessageFormatElement$refs;
typedef struct _jc_java_text_MessageFormat__24MessageFormatElement$nonrefs	_jc_java_text_MessageFormat__24MessageFormatElement$nonrefs;
typedef struct _jc_java_text_MessageFormat__24MessageFormatElement$object	_jc_java_text_MessageFormat__24MessageFormatElement$object;

typedef struct _jc_java_text_MessageFormat__24MessageFormatElement$fields_struct	_jc_java_text_MessageFormat__24MessageFormatElement$fields_struct;
typedef const struct _jc_java_text_MessageFormat__24MessageFormatElement$vmethods	_jc_java_text_MessageFormat__24MessageFormatElement$vmethods;
typedef const struct _jc_java_text_MessageFormat__24MessageFormatElement$vtable	_jc_java_text_MessageFormat__24MessageFormatElement$vtable;
typedef const struct _jc_java_text_MessageFormat__24MessageFormatElement$vtype	_jc_java_text_MessageFormat__24MessageFormatElement$vtype;

// Class fields structure
struct _jc_java_text_MessageFormat__24MessageFormatElement$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Number;
	struct _jc_java_lang_Class$object	*class__24java__24util__24Date;
};
extern _jc_java_text_MessageFormat__24MessageFormatElement$fields_struct _jc_java_text_MessageFormat__24MessageFormatElement$class_fields;

// Constructors
extern void _jc_java_text_MessageFormat__24MessageFormatElement$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_text_MessageFormat__24MessageFormatElement$object *) _JC_JCNI_ATTR;
extern void _jc_java_text_MessageFormat__24MessageFormatElement$method$_init$31edac7687292d89(_jc_env *, struct _jc_java_text_MessageFormat__24MessageFormatElement$object *, struct _jc_java_text_MessageFormat__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_text_MessageFormat__24MessageFormatElement$method$setLocale$6eaa1a56408d8bc9(_jc_env *, struct _jc_java_text_MessageFormat__24MessageFormatElement$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_text_MessageFormat__24MessageFormatElement$method_info$setLocale$6eaa1a56408d8bc9;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_java_text_MessageFormat__24MessageFormatElement$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_text_MessageFormat__24MessageFormatElement$vmethods {
	void	(*setLocale$6eaa1a56408d8bc9)(_jc_env *, struct _jc_java_text_MessageFormat__24MessageFormatElement$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_text_MessageFormat__24MessageFormatElement$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_text_MessageFormat__24MessageFormatElement$vmethods	java_text_MessageFormat__24MessageFormatElement;
};

// Vtype
struct _jc_java_text_MessageFormat__24MessageFormatElement$vtype {
	_jc_type			type;
	_jc_java_text_MessageFormat__24MessageFormatElement$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_MessageFormat__24MessageFormatElement$sub_refs {
	struct _jc_java_text_Format$object	*setFormat;
	struct _jc_java_text_Format$object	*format;
	struct _jc_java_lang_Class$object	*formatClass;
	struct _jc_java_lang_String$object	*type;
	struct _jc_java_lang_String$object	*style;
	struct _jc_java_lang_String$object	*trailer;
};

// Reference instance fields (object)
struct _jc_java_text_MessageFormat__24MessageFormatElement$refs {
    _jc_java_text_MessageFormat__24MessageFormatElement$sub_refs	java_text_MessageFormat__24MessageFormatElement;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_MessageFormat__24MessageFormatElement$sub_nonrefs {
	jint	argNumber;
};

// Non-reference instance fields (object)
struct _jc_java_text_MessageFormat__24MessageFormatElement$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_text_MessageFormat__24MessageFormatElement$sub_nonrefs	java_text_MessageFormat__24MessageFormatElement;
};

// Object instance structure
struct _jc_java_text_MessageFormat__24MessageFormatElement$object {
	_jc_java_text_MessageFormat__24MessageFormatElement$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_MessageFormat__24MessageFormatElement$vtype	*vtype;
	_jc_java_text_MessageFormat__24MessageFormatElement$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_MessageFormat__24MessageFormatElement$vtype _jc_java_text_MessageFormat__24MessageFormatElement$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_MessageFormat__24MessageFormatElement, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_MessageFormat__24MessageFormatElement$class_object;

#endif	/* _JC_java_text_MessageFormat__24MessageFormatElement_H_ */
